import React from 'react';
import ReactDOM from 'react-dom';
import { scaleBand, scaleLinear, extent, format } from 'd3';

import { useData } from './useData';

import { GroupChart } from './GroupChart';

const width = 960;
const height = 500;
const margin = { top: 20, right: 150, bottom: 40, left: 100 };
const innerWidth = width - margin.right - margin.left;
const innerHeight = height - margin.top - margin.bottom;
const xLabelOffset = 25;
const xTitleOffset = 60;
const yLabelOffset = 15;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const gValue = (d) => d.species;
  const xValue = (d) => d.sepal_length;
  const yValue = (d) => d.sepal_width;

  const gScale = scaleBand()
    .domain(data.map(gValue))
    .range([0, innerHeight])
    .paddingInner(0.3)
    .paddingOuter(0);
  const gHeight = gScale.bandwidth();

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  	.nice();

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([gHeight, 0])
  	.nice(5);

  const xFormatSpec = format('.2s');
  const xLabelFormat = (s) => xFormatSpec(s).replace('G', 'B');

  return (
    <div className="App">
      <svg width={width} height={height}>
        <g transform={`translate(${margin.left}, ${margin.top})`}>

          {gScale.domain().map((sp) => {


            return (
              <GroupChart
                data={data.filter((d) => d.species === sp)}
                xScale={xScale}
                xValue={xValue}
                xLabelFormat={xLabelFormat}
                xLabelOffset={xLabelOffset}
                yScale={yScale}
                yValue={yValue}
                yLabelOffset={yLabelOffset}
                innerWidth={innerWidth}
                innerHeight={gHeight}
                y={gScale(sp)}
                title={sp}
              />
            );
          })}
        </g>
      </svg>
    </div>
  );
};

ReactDOM.render(<App />, document.getElementById('root'));
